oc\_ocdm.graph.entities package
===============================

Modules
-------
.. toctree::
   :maxdepth: 1

   entities/oc_ocdm.graph.entities.bibliographic_entity
   entities/oc_ocdm.graph.entities.identifier

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   entities/oc_ocdm.graph.entities.bibliographic
